Facets
******

Plone's default search form is overridden to provide faceting support.
The available facets can be configured in the control panel.
The provided search form is currently more of an example and not used in many real world projects.
You likely want to override it with a custom implementation for your specific site.

Starting with Plone 4.2, Plone will contain a modernized search form whose UI supports faceting more naturally.
At some point `collective.solr` will extend this new search form rather than providing its own.
